#include "id3ed.h"

void
set_id3v2(const char *name)
{
}


char *
ucs4_cvt(id3_ucs4_t const *ucs4)
{
	if (latin1_output) 
		return (char*)id3_ucs4_latin1duplicate(ucs4);
	else
		return (char*)id3_ucs4_utf8duplicate(ucs4);
}

void
add_stringlist(gl_list_t list, struct id3_frame *frame,
	       union id3_field *field)
{
	unsigned i, nstrings = id3_field_getnstrings(field);
	for (i = 0; i < nstrings; i++) {
		id3_ucs4_t const *ucs4;
		char *str;
		
		ucs4 = id3_field_getstrings(field, i);
		if (!ucs4)
			continue;
		if (strcmp(frame->id, ID3_FRAME_GENRE) == 0)
			ucs4 = id3_genre_name(ucs4);
		str = ucs4_cvt(ucs4);
		gl_list_add_last(list, str);
	}
}

void
add_field(gl_list_t list, struct id3_frame *frame, union id3_field *field)
{
	id3_ucs4_t const *ucs4;
	char *str;
	
	switch (id3_field_type(field)) {
	case ID3_FIELD_TYPE_TEXTENCODING:
		break;
	case ID3_FIELD_TYPE_LATIN1:
	case ID3_FIELD_TYPE_LATIN1FULL:
	case ID3_FIELD_TYPE_LATIN1LIST:
		break;
	case ID3_FIELD_TYPE_STRING:
		break;
	case ID3_FIELD_TYPE_STRINGFULL:
		ucs4 = id3_field_getfullstring(field);
		str = ucs4_cvt(ucs4);
		gl_list_add_last(list, str);
		break;
	case ID3_FIELD_TYPE_STRINGLIST:
		add_stringlist(list, frame, field);
		break;
	case ID3_FIELD_TYPE_LANGUAGE:
	case ID3_FIELD_TYPE_FRAMEID:
	case ID3_FIELD_TYPE_DATE:
	case ID3_FIELD_TYPE_INT8:
	case ID3_FIELD_TYPE_INT16:
	case ID3_FIELD_TYPE_INT24:
	case ID3_FIELD_TYPE_INT32:
	case ID3_FIELD_TYPE_INT32PLUS:
	case ID3_FIELD_TYPE_BINARYDATA:;
	}
}

gl_list_t 
frame_to_list(struct id3_frame *frame)
{
	gl_list_t list;
	unsigned i, j, nstrings;
	union id3_field *field;

	list = new_string_list(true);
	for (i = 0; field = id3_frame_field(frame, i); i++) 
		add_field(list, frame, field);
	return list;
}

static void
show_tags(struct id3_tag *tag)
{
	struct id3_frame *frame;
	unsigned i;

	for (i = 0; frame = id3_tag_findframe(tag, NULL, i); i++) {
		gl_list_t list = frame_to_list(frame);
		if (gl_list_size(list) > 0)
			ed_list_add_item(frame->id, list);
		else
			gl_list_free(list);
	}
	ed_list_print();
}

void
query_id3v2(const char *name)
{
	struct id3_file *file;
	struct id3_tag *tag;
	
	file = id3_file_open(name, ID3_FILE_MODE_READONLY);
	if (!file)
		error(1, errno, "cannot open file %s", name);

	tag = id3_file_tag(file);
	if (tag) 
		show_tags(tag);
	
	id3_file_close(file);
}

void
del_id3v2(const char *name)
{
}
